@@ -26,6 +26,7 @@
   var DataTable = function ( element, options ) {
     this.$element = $(element);
     this.options = options;
+    this.pendingRequest = null;
     this.enabled = true;
     this.columns = [];
     this.rows = [];
@@ -44,10 +45,8 @@
     this.$default = this.$element.children().length ?
       this.$element.children() :
       $("<div></div>")
-// ------------- Start ntop Patch ---------------
         .addClass("alert alert-danger")
-// ------------- End ntop Patch ---------------        
-        .html("No Results Found");
+        .html(i18n.no_results_found);
 
     this.$element.addClass("clearfix");
 
@@ -107,24 +106,31 @@
                 , filter: o.filter
               }) );
         if(o.url !== "") {
-          $.ajax({
+          var req_data = (typeof o.post === "function") ? o.post() : o.post;
+
+          if(this.pendingRequest)
+            this.pendingRequest.abort();
+
+          this.pendingRequest = $.ajax({
               url: o.url
-// ------------- Start ntop Patch ---------------
             , type: "GET"
             , dataType: "json"
-            , data: $.extend({}, o.post, {
+            , data: $.extend({}, req_data, {
                   currentPage: o.currentPage
                 , perPage: o.perPage
                 , sortColumn: (o.sort.length > 0) ? o.sort[0][0] : null
                 , sortOrder: (o.sort.length > 0) ? o.sort[0][1] : null
- // ------------- End ntop Patch -----------------
                 , filter: o.filter
               })
-            , success: function( res ) {
-                that.resultset = res;
+            , success: function(res, status, xhr) {
+                that.pendingRequest = null;
 
-                if(!res || res === undefined || !res.data || res.data.length == 0) {
-                  showError.call(that);
+                if(o.dataAdapter)
+                  res = o.dataAdapter(res, o);
+
+                that.resultset = res;                  
+                if(!res || res === undefined || !res.data || (res.data.length == 0 && !o.forceTable) ) {
+                  showError.call(that, res);
                   return;
                 }
 
@@ -163,7 +169,7 @@
                   that.$bottom_details.append(that.pagination().clone(true));
 
                 // update the details for the results
-                that.details();
+                if(! o.hideDetails)     that.details();
 
                 // initialize the toolbar
                 _initToolbar.call(that);
@@ -174,9 +180,11 @@
 
                 that.loading( false );
               }
-            , error: function( e ) {
-                if(o.debug) console.log(e);
-                showError.call(that);
+            , error: function(xhr, status, e) {
+                that.pendingRequest = null;
+                if(status !== "abort")
+                  console.error("Datatable: error while loading data: " + e);
+                showError.call(that, null, status, e);
 
                 that.loading( false );
               }
@@ -186,24 +194,28 @@
 
     , loading: function ( show ) {
         var $e = this.$element;
+        var o = this.options;
+
+        if(o.customLoading) {
+          o.customLoading(this, show);
+          return;
+        }
 
         if(!this.$loading) {
           this.$loading = $("<div></div>")
             .css({
                 position: 'absolute'
-              , top: parseInt($e.position().top) + 5
+              , top: parseInt($e.position().top) + 5 + (o.loadingYOffset || 0)
               , left: parseInt($e.position().left) + parseInt($e.css("marginLeft")) + Math.floor($e.width() / 4)
               , width: Math.floor($e.width() / 2) + "px"
             })
             .append(
               $("<div></div>")
-// ------------- Start ntop Patch ---------------              
                 .addClass("progress progress-striped")
                 .append(
                   $("<div></div>")
                     .addClass("progress-bar progress-bar-info")
                     .attr('style', "width: 40%")
-// ------------- End ntop Patch -----------------                    
                 )
             )
             .appendTo(document.body)
@@ -249,7 +261,7 @@
         }
         else if(o.title !== '' && !this.$section_header) {
           this.$section_header = $("<h2></h2>")
-            .text(o.title)
+            .html(o.title)
             .append(this.$toolbar);
           $e.before(this.$section_header);
         }
@@ -280,7 +292,7 @@
         end = (o.currentPage * o.perPage);
         if(end > o.totalRows) end = o.totalRows;
 
-        $('<div class="pull-left"><p>Showing ' + start + ' to ' + end + ' of ' + o.totalRows + ' rows</p></div>')
+        $('<div class="pull-left"><p>' + i18n.showing_x_to_y_rows.sformat(start, end, o.totalRows) + '</p></div>')
           .prependTo(this.$bottom_details);
       }
 
@@ -657,7 +669,7 @@
     var o = this.options;
 
     // create the perpage dropdown
-    _initPerPage.call(this);
+    if(! o.hidePerPage)   _initPerPage.call(this);
 
     // handle filter options
     if(o.filterModal)     _initFilterModal.call(this);
@@ -876,7 +888,7 @@
     // per page options and current filter/sorting
     var $perpage_select = $("<a></a>")
       .addClass("btn dropdown-toggle")
-      .data("content", "Change the number of rows per page.")
+      .data("content", i18n.change_number_of_rows + ".")
       .attr("data-toggle", "dropdown")
       .html(o.perPage + "&nbsp;")
       .css({ fontWeight: 'normal' })
@@ -902,7 +914,7 @@
             .click(function() { _updatePerPage.call(this, that); return false; })
         , $('<li data-value="100"><a href="#">100</a></li>')
             .click(function() { _updatePerPage.call(this, that); return false; })
-        , $('<li data-value="150"><a href="#">200</a></li>')
+        , $('<li data-value="200"><a href="#">200</a></li>')
             .click(function() { _updatePerPage.call(this, that); return false; })
       );
     this.buttons.push($perpage_values);
@@ -1029,7 +1041,7 @@
     return false;
   }
 
-  function showError() {
+  function showError(data, status, err_msg) {
     var o = this.options
       , $e = this.$element;
 
@@ -1044,7 +1056,29 @@
 
     this.loading( false );
 
-    if(this.$default) $e.append(this.$default);
+    var custom_no_res = null;
+
+    if(o.noResultsCallback)
+      custom_no_res = o.noResultsCallback(this, data);
+
+    if(custom_no_res) {
+      $e.append(custom_no_res);
+    } else if(err_msg && (status != "abort")) {
+      $e.append($("<div></div>")
+        .addClass("alert alert-danger")
+        .html(err_msg));
+    } else if(data && typeof data.error === "string") {
+      $e.append($("<div></div>")
+        .addClass("alert alert-danger")
+        .html(data.error));
+    } else if(o.noResultsMessage) {
+      var msg = o.noResultsMessage(this, data);
+
+      $e.append($("<div></div>")
+        .addClass("alert alert-danger")
+        .html(msg));
+    } else if(this.$default)
+      $e.append(this.$default);
   }
 
   function runFilter(that) {
