@@ -1,12 +1,14 @@
 --
--- (C) 2017 - ntop.org
+-- (C) 2017-18 - ntop.org
 --
 
 dirs = ntop.getDirs()
 package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
 require "lua_utils"
 local host_pools_utils = require "host_pools_utils"
+local discover = require "discover_utils"
 local template = require "template_utils"
+local ts_utils = require "ts_utils"
 
 if(ntop.isPro()) then
   package.path = dirs.installdir .. "/pro/scripts/lua/modules/?.lua;" .. package.path
@@ -26,23 +28,11 @@ if _POST["edit_pools"] ~= nil then
   for pool_id, pool_name in pairs(config) do
     -- Filter pool ids only
     if tonumber(pool_id) ~= nil then
-      local children_safe = nil
-      if config["_csafe_"..pool_id] ~= nil then
-        children_safe = config["_csafe_"..pool_id]
-      end
-
-      local enforce_quotas_per_pool_member = nil
-      if config["_qts_per_member_"..pool_id] ~= nil then
-        enforce_quotas_per_pool_member = config["_qts_per_member_"..pool_id]
-      end
-
-      -- create or rename
-      host_pools_utils.createPool(ifId, pool_id, pool_name, children_safe, enforce_quotas_per_pool_member)
-
-      if(interface.isBridgeInterface(ifId) == true) then
-        -- create default shapers
-        shaper_utils.initDefaultShapers(ifid, pool_id)
-      end
+      host_pools_utils.createPool(ifId, pool_id, pool_name,
+				  nil --[[ children_safe ]],
+				  nil --[[ enforce_quotas_per_pool_member ]],
+				  nil --[[ enforce_shapers_per_pool_member ]],
+				  true --[[ create or rename ]])
     end
   end
 
@@ -52,10 +42,6 @@ elseif _POST["pool_to_delete"] ~= nil then
   local pool_id = _POST["pool_to_delete"]
   host_pools_utils.deletePool(ifId, pool_id)
 
-  if(interface.isBridgeInterface(ifId) == true) then
-    shaper_utils.flushPoolRules(ifId, pool_id)
-  end
-
   -- Note: this will also reload the shaping rules
   interface.reloadHostPools()
 elseif (_POST["edit_members"] ~= nil) then
@@ -82,6 +68,13 @@ elseif (_POST["edit_members"] ~= nil) then
       icon = parts[3],
     }
 
+    -- Convention: use uppercase letters for mac, lowercase for ip
+    if isMacAddress(new_member) then
+      new_member = string.upper(new_member)
+    else
+      new_member = string.lower(new_member)
+    end
+
     if (not isEmptyString(old_member)) and (not isValidPoolMember(assembled.old_member)) then
       http_lint.validationError(_POST, "old_member", new_member, "Invalid pool member")
     end
@@ -174,9 +167,14 @@ elseif (_POST["edit_members"] ~= nil) then
         setHostAltName(host_key, alias)
       end
 
-      local icon = value.icon
-      if((not is_new_member) or (not isEmptyString(icon))) then
-        setHostIcon(host_key, icon)
+      local icon = tonumber(value.icon)
+
+      if (not isEmptyString(icon))
+            and ((not is_new_member) or (icon ~= 0))
+            and isMacAddress(new_member)
+            and new_member ~= "00:00:00:00:00:00" then
+        setCustomDeviceType(new_member, icon)
+        interface.setMacDeviceType(new_member, icon, true --[[ overwrite ]])
       end
     end
   end
@@ -222,13 +220,7 @@ function printMemberVlanField(member_str)
 end
 
 function printIconField(member_str)
-  print[[<select name="icon_member_' + ]] print(member_str) print[[ + '" class="form-control">]]
-  for k,v in getHostIcons() do
-      print[[<option value="]] print(v) print[["]]
-      if(v == icon) then print[[ selected]] end
-      print[[>]] print(k) print[[</option>]]
-  end
-  print[[</select>]]
+  discover.printDeviceTypeSelector("", "icon_member_' + " .. member_str .. " + '")
 end
 
 function printAliasField(member_str)
@@ -259,6 +251,7 @@ end
 
 -- We are passing too much _POST data, no more than 5 members allowed
 local perPageMembers = "5"
+local perPagePools = "10"
 
 local members_filtering = _GET["members_filter"]
 local manage_url = "?ifid="..ifId.."&page=pools&pool="..selected_pool.id.."#manage"
@@ -279,15 +272,17 @@ print [[
 ]]
 
 print('<td style="white-space:nowrap; padding-right:1em;">') print(i18n("host_pools.pool")) print(': <select id="pool_selector" class="form-control pool-selector" style="display:inline;" onchange="document.location.href=\'?ifid=') print(ifId.."") print('&page=pools&pool=\' + $(this).val() + \'#manage\';">')
-print(poolDropdown(selected_pool.id))
+print(poolDropdown(ifId, selected_pool.id))
 print('</select>')
 
 local no_pools = (#available_pools <= 1)
 
 local ifstats = interface.getStats()
-local is_bridge_iface = (ifstats["bridge.device_a"] ~= nil) and (ifstats["bridge.device_b"] ~= nil)
-if is_bridge_iface and selected_pool.id ~= host_pools_utils.DEFAULT_POOL_ID then
-  print("<a href='/lua/if_stats.lua?ifid=") print(ifId.."") print("&page=filtering&pool="..(selected_pool.id).."#protocols' title='Manage Traffic Policies'><i class='fa fa-cog' aria-hidden='true'></i></a>")
+
+if selected_pool.id ~= host_pools_utils.DEFAULT_POOL_ID then
+    if ntop.getCache("ntopng.prefs.host_pools_rrd_creation") == "1" and ts_utils.exists("host_pool:traffic", {ifid=ifId, pool=selected_pool.id}) then
+      print("&nbsp; <a href='"..ntop.getHttpPrefix().."/lua/pool_details.lua?pool="..selected_pool.id.."&page=historical' title='Chart'><i class='fa fa-area-chart'></i></a>")
+    end
 end
 
 print('</td>\n')
@@ -321,9 +316,9 @@ print(
       base_id     = "t_member",
       action      = ntop.getHttpPrefix() .. "/lua/if_stats.lua#manage",
       parameters  = {
-                      pool=selected_pool.id,
-                      ifid=tostring(ifId),
-                      page="pools",
+                      pool = selected_pool.id,
+                      ifid = tostring(ifId),
+                      page = "pools",
                     },
       json_key    = "key",
       query_field = "members_filter",
@@ -356,14 +351,14 @@ end
       </form>
       ]]
 
-if not ntop.isEnterprise() then
-  print[[<span style="float:left;">]]
-  print(i18n("notes"))
-  print[[<ul>
-      <li>]] print(i18n("host_pools.max_members_message", {maxnum=host_pools_utils.LIMITED_NUMBER_POOL_MEMBERS})) print[[</li>
+  if not ntop.isEnterprise() and not ntop.isnEdgeEnterprise() then
+     print[[<span style="float:left;">]]
+     print(i18n("notes"))
+     print[[<ul>
+      <li>]] print(i18n("host_pools.max_members_message", {maxnum = host_pools_utils.LIMITED_NUMBER_POOL_MEMBERS})) print[[</li>
     </ul>
   </span>]]
-end
+  end
 
 print[[
       <button id="emptyPoolButton" class="btn btn-default" onclick="$('#empty_pool_dialog').modal('show');" style="float:right; margin-right:1em;"><i class="fa fa-trash" aria-hidden="true"></i> ]] print(i18n("host_pools.empty_pool")) print[[</button>
@@ -378,15 +373,11 @@ print[[
         <button class="btn btn-primary" style="float:right; margin-right:1em;" disabled="disabled" type="submit">]] print(i18n("save_settings")) print[[</button>
       </form>
       <br/><br/>
-      NOTES:
+      ]] print(i18n("notes")) print[[
       <ul>
-        <li>A pool cannot be deleted if there is any Captive Portal user associated. ]]
+        <li>]] print(i18n("host_pools.cannot_delete_cp")) print[[.</li>]]
 
-if isCaptivePortalActive() then
-  print [[Manage Captive Portal users <a href="]] print(ntop.getHttpPrefix()) print[[/lua/admin/users.lua?captive_portal_users=1">here</a>.</li>]]
-end
-
-if not ntop.isEnterprise() then
+if not ntop.isEnterprise() and not ntop.isnEdgeEnterprise() then
   print("<li>"..i18n("host_pools.max_pools_message", {maxnum=host_pools_utils.LIMITED_NUMBER_USER_HOST_POOLS}).."</li>")
 end
 
@@ -449,7 +440,7 @@ print(
       title   = i18n("host_pools.change_member_pool"),
       message = i18n("host_pools.select_new_pool", {member='<span id="change_member_pool_dialog_member"></span>'}) ..
         '<br><br><select class="form-control" id="changed_host_pool" style="width:15em;">'..
-        poolDropdown("", {[selected_pool.id]=true, [host_pools_utils.DEFAULT_POOL_ID]=true})..
+        poolDropdown(ifId, "", {[selected_pool.id]=true, [host_pools_utils.DEFAULT_POOL_ID]=true})..
         '</select>',
       custom_alert_class = "",
       confirm = i18n("host_pools.change_pool"),
@@ -473,16 +464,19 @@ print[[
         vlan_field.attr("disabled", true);
         vlanicon_disabled = false;
       } else {
-        var is_cidr = is_network_mask(member, true);
+        var cidr = is_network_mask(member, true);
 
-        if (is_cidr) {
+        if (cidr) {
           vlan_field.removeAttr("disabled");
+          select_field.attr("disabled", true);
 
-          if ((is_cidr.type == "ipv4" && is_cidr.mask != 32) ||
-             ((is_cidr.type == "ipv6" && is_cidr.mask != 128)))
-            vlanicon_disabled = true
-          else
+          if((cidr.type == "ipv6" && cidr.mask == 128)
+              || (cidr.type == "ipv4" && cidr.mask == 32)) {
+            /* Custom alias only allowed for IP addresses */
             vlanicon_disabled = false;
+          } else {
+            vlanicon_disabled = true;
+          }
         }
       }
 
@@ -490,6 +484,9 @@ print[[
         icon_field.attr("disabled", vlanicon_disabled);
         select_field.attr("disabled", vlanicon_disabled);
       }
+
+      if (]] print(ternary(ifstats.has_macs, "false", "true")) print[[)
+        select_field.attr("disabled", true);
     }
     
     /* Make the pair address,vlan unique */
@@ -560,6 +557,28 @@ print[[
 
       return count == 1;
     }
+
+    function poolNameUnique(input) {
+      /* First update the host_pools names */
+      datatableForEachRow("#table-create", function() {
+        var pool_id = $("td:nth-child(1)", $(this)).html();
+        var pool_name = $("td:nth-child(2) input", $(this)).val();
+
+        for (var i=0; i<host_pools.length; i++)
+          if (host_pools[i].id == pool_id)
+            host_pools[i].name = pool_name;
+      });
+
+      var name = input.val();
+      var count = 0;
+
+      for (i=0; i<host_pools.length; i++) {
+        if (host_pools[i].name === name)
+          count++;
+      }
+
+      return count == 1;
+    }
 ]]
 if members_filtering ~= nil then
   print[[$("#pool_selector").attr("disabled", true);]]
@@ -582,9 +601,7 @@ print [[
       custom: {
          member: memberValidator,
          address: addressValidator,
-         unique: makeUniqueValidator(function(field) {
-            return $('input[name^="pool_"]', $("#table-create-form"));
-         }),
+         unique: poolNameUnique,
       }, errors: {
          member: "]] print(i18n("host_pools.duplicate_member")) print[[.",
          address: "]] print(i18n("host_pools.invalid_member")) print[[.",
@@ -602,7 +619,7 @@ print [[
       var newid = "member_" + member_id;
       numPoolMembers++;
 
-      var tr = $('<tr id=' + newid + '><td>]] printMemberAddressField('member_id') print[[</td><td class="text-center">]] printMemberVlanField('member_id') print[[</td><td>]] printAliasField('member_id') print[[</td><td>]] printIconField('member_id') print[[</td><td class="text-center ]] if not (isCaptivePortalActive()) then print(" hidden") end print[[">Persistent</td><td class="text-center"></td></tr>');
+      var tr = $('<tr id=' + newid + '><td>]] printMemberAddressField('member_id') print[[</td><td class="text-center">]] printMemberVlanField('member_id') print[[</td><td>]] printAliasField('member_id') print[[</td><td>]] printIconField('member_id') print[[</td><td class="text-center hidden">Persistent</td><td class="text-center"></td></tr>');
       datatableAddDeleteButtonCallback.bind(tr)(6, "datatableUndoAddRow('#" + newid + "', ']] print(i18n("host_pools.empty_pool")) print[[', '#addPoolMemberBtn', 'decPoolMembers')", "]] print(i18n('undo')) print[[");
       $("#table-manage table").append(tr);
       $("input", tr).first().focus();
@@ -690,16 +707,6 @@ print [[
               textAlign: 'center',
               whiteSpace: 'nowrap',
             }
-         }, {
-            title: "Residual Lifetime",
-            field: "column_residual",
-]] if not (isCaptivePortalActive()) then
-  print[[   hidden: true,]]
-end
-print[[            css : {
-               width: '10%',
-               textAlign: 'center',
-            }
          }, {
             title: "]] print(i18n("actions")) print[[",
             css : {
@@ -729,8 +736,8 @@ print[[            css : {
             var vlan = $("td:nth-child(2)", $(this));
             var alias = $("td:nth-child(3)", $(this));
             var icon = $("td:nth-child(4)", $(this));
-            var link_value = $("td:nth-child(7)", $(this)).html().replace(/&nbsp;/gi,'');
-            var editable = $("td:nth-child(8)", $(this)).html() == "true";
+            var link_value = $("td:nth-child(6)", $(this)).html().replace(/&nbsp;/gi,'');
+            var editable = $("td:nth-child(7)", $(this)).html() == "true";
 
             var member_id = addedMemberCtr++;
             curDisplayedMembers++;
@@ -757,9 +764,10 @@ print[[            css : {
             alias.html(input);
 
             /* Icon field */
-            var input = $(']] printIconField('member_id') print[[');
+            var div = $(']] printIconField('member_id') print[[');
+            input = $("select", div);
             input.val(icon.html().replace(/&nbsp;/gi,''));
-            icon.html(input);
+            icon.html(div);
 
             /* Make vlan editable */
             var input = $(']] printMemberVlanField('member_id') print[[');
@@ -780,17 +788,17 @@ print[[            css : {
 ]]
 
 if #available_pools > 2 then
-  print[[   datatableAddActionButtonCallback.bind(this)(6, "change_member_id ='" + member_id + "'; $('#change_member_pool_dialog_member').html('" + value +"'); $('#change_member_pool_dialog').modal('show');", "]] print(i18n("host_pools.change_pool")) print[[");]]
+  print[[   datatableAddActionButtonCallback.bind(this)(5, "change_member_id ='" + member_id + "'; $('#change_member_pool_dialog_member').html('" + value +"'); $('#change_member_pool_dialog').modal('show');", "]] print(i18n("host_pools.change_pool")) print[[");]]
 end
 
 print[[
-            datatableAddLinkButtonCallback.bind(this)(6, link_value, "]] print(i18n("host_pools.view")) print[[");
+            datatableAddLinkButtonCallback.bind(this)(5, link_value, "]] print(i18n("host_pools.view")) print[[");
             if (!link_value) $("td:nth(5) a:nth(1)", this).css("visibility", "hidden");
-            datatableAddDeleteButtonCallback.bind(this)(6, "delete_member_id ='" + member_id + "'; $('#delete_member_dialog_member').html('" + value +"'); $('#delete_member_dialog').modal('show');", "]] print(i18n('delete')) print[[");
+            datatableAddDeleteButtonCallback.bind(this)(5, "delete_member_id ='" + member_id + "'; $('#delete_member_dialog_member').html('" + value +"'); $('#delete_member_dialog').modal('show');", "]] print(i18n('delete')) print[[");
           });
 
           if(numPoolMembers === 0)
-            numPoolMembers = datatableGetTotalItems('#table-manage-form');
+            numPoolMembers = $("#table-manage").data("datatable").resultset.num_pool_members || 0;
           aysResetForm('#table-manage-form');
         }
 
@@ -865,9 +873,17 @@ print[[
 
 print [[
   <script>
-    var nextPoolId = 1;
-    var numPools = 0;
-    var maxPoolNum = ]] print(tostring(host_pools_utils.LIMITED_NUMBER_USER_HOST_POOLS)) print[[;
+    /* Assumption: this is sorted by pool id with possible gaps */
+    var host_pools = ]] print(tableToJsObject(available_pools)) print[[;
+    var maxPoolsNum = ]] print(tostring(host_pools_utils.LIMITED_NUMBER_TOTAL_HOST_POOLS)) print[[;
+
+    function nextPoolId() {
+      for (var i=0; i<host_pools.length-1; i++)
+        if (parseInt(host_pools[i].id) + 1 < parseInt(host_pools[i+1].id))
+          return parseInt(host_pools[i].id) + 1;
+
+      return parseInt(host_pools[host_pools.length-1].id) + 1;
+    }
 
     function deletePool(pool_id) {
       var params = {};
@@ -882,53 +898,35 @@ print [[
     }
 
     function onPoolAddUndo(newid) {
-      var pool_id = parseInt(newid.split("added_pool_")[1]);
-      if (pool_id)
-        nextPoolId = Math.min(nextPoolId, pool_id);
-      numPools--;
-    }
-
-    function makeChildrenSafeInput(value) {
-      return $('<input name="children_safe" type="checkbox"' + ((value == true) ? " checked" : "") + '/>');
-    }
-
-    function makeEnforceQuotasPerPoolMemberInput(value) {
-      return $('<input name="enforce_quotas_per_pool_member" type="checkbox"' + ((value == true) ? " checked" : "") + '/>');
+      var pool_id = newid.split("added_pool_")[1];
+      if (pool_id) {
+        for (var i=0; i<host_pools.length; i++) {
+          if (parseInt(host_pools[i].id) == pool_id) {
+            /* Remove the element at index i */
+            host_pools.splice(i, 1);
+            break;
+          }
+        }
+      }
     }
 
     function addPool() {
-      var pool_id = nextPoolId;
+      var pool_id = nextPoolId();
 
-      while (nextPoolId < maxPoolNum) {
-        nextPoolId = nextPoolId+1;
+      if (pool_id < maxPoolsNum) {
+        if (datatableIsEmpty("#table-create"))
+          datatableRemoveEmptyRow("#table-create");
 
-        // find a new gap
-        if ($("#table-create input[name='pool_" + nextPoolId +"']").length == 0)
-          break;
-      }
-
-      if (datatableIsEmpty("#table-create"))
-         datatableRemoveEmptyRow("#table-create");
-
-      if (pool_id < maxPoolNum) {
-        numPools++;
         var newid = "added_pool_" + pool_id;
 
+        /* Add at 'pool_id' position */
+        host_pools.splice(pool_id, 0, {id:pool_id});
+
         var tr = $('<tr id=' + newid + '><td class="text-center hidden">' + pool_id + '</td><td>]]
-          printPoolNameField('pool_id') print[[</td><td class="hidden"></td><td class="text-center]]
-          if not is_bridge_iface then print(" hidden") end
-          print[["></td><td class="text-center]]
-          if not is_bridge_iface or not ntop.isEnterprise() then print(" hidden") end
-          print[["></td><td class="text-center"></td></tr>');
+printPoolNameField('pool_id') print[[</td><td class="hidden"></td><td class="text-center"></td></tr>');
 
-        var children_safe = $("td:nth-child(4)", tr);
-        children_safe.html(makeChildrenSafeInput());
-
-        var enforce_quotas_per_pool_member = $("td:nth-child(5)", tr);
-	enforce_quotas_per_pool_member.html(makeEnforceQuotasPerPoolMemberInput());
-
-        datatableAddDeleteButtonCallback.bind(tr)(6, "datatableUndoAddRow('#" + newid + "', ']] print(i18n("host_pools.no_pools_defined")) print[[', '#addNewPoolBtn', 'onPoolAddUndo')", "]] print(i18n('undo')) print[[");
-        datatableOrderedInsert("#table-create table", 1, tr, pool_id);
+        datatableAddDeleteButtonCallback.bind(tr)(4, "datatableUndoAddRow('#" + newid + "', ']] print(i18n("host_pools.no_pools_defined")) print[[', '#addNewPoolBtn', 'onPoolAddUndo')", "]] print(i18n('undo')) print[[");
+        $("#table-create table").append(tr);
         $("input", tr).focus();
 
         aysRecheckForm("#table-create-form");
@@ -938,8 +936,16 @@ print [[
     }
 
     function recheckPoolAddButton() {
-      if(numPools >= maxPoolNum)
+      /* TODO use array size and perPage */
+      var displayed_items = datatableGetNumDisplayedItems("#table-create");
+      var numPools = host_pools.length;
+
+      if ((numPools >= maxPoolsNum)
+          || (displayed_items > ]] print(perPagePools) print[[)
+          || (! datatableIsLastPage("#table-create-form")))
         $("#addNewPoolBtn").attr("disabled", "disabled");
+      else
+        $("#addNewPoolBtn").removeAttr("disabled");
     }
 
     $("#table-create").datatable({
@@ -947,11 +953,10 @@ print [[
    print (ntop.getHttpPrefix())
    print [[/lua/get_host_pools.lua?ifid=]] print(ifId.."") print[[",
       title: "",
-      hidePerPage: true,
-      hideDetails: true,
-      showPagination: false,
-      perPage: ]] print(tostring(host_pools_utils.MAX_NUM_POOLS)) print[[,
+      showPagination: true,
       forceTable: true,
+      hidePerPage: true,
+      perPage: ]] print(perPagePools) print[[,
 
       buttons: [
          '<a id="addNewPoolBtn" onclick="addPool()" role="button" class="add-on btn" data-toggle="modal"><i class="fa fa-plus" aria-hidden="true"></i></a>'
@@ -969,32 +974,6 @@ print [[
          }, {
             field: "column_pool_undeletable",
             hidden: true,
-         }, {
-            title: "]] print(i18n("host_pools.children_safe")) print[[",
-            field: "column_children_safe",
-            ]]
-     if not is_bridge_iface then
-        print("hidden: true,")
-     end
-     print[[
-            css : {
-               width: '7%',
-               textAlign: 'center',
-               whiteSpace: 'nowrap',
-            }
-         }, {
-            title: "]] print(i18n("host_pools.enforce_quotas_per_pool_member")) print[[",
-            field: "column_enforce_quotas_per_pool_member",
-            ]]
-     if not is_bridge_iface or not ntop.isEnterprise() then
-        print("hidden: true,")
-     end
-     print[[
-            css : {
-               width: '7%',
-               textAlign: 'center',
-	       whiteSpace: 'nowrap',
-            }
          }, {
             title: "]] print(i18n("actions")) print[[",
             css : {
@@ -1015,9 +994,7 @@ print [[
             var pool_id = $("td:nth-child(1)", $(this)).html();
             var pool_name = $("td:nth-child(2)", $(this));
             var pool_undeletable = $("td:nth-child(3)", $(this)).html() === "true";
-            var children_safe = $("td:nth-child(4)", $(this));
-            var enforce_quotas_per_pool_member = $("td:nth-child(5)", $(this));
-            var pool_link = $("td:nth-child(7)", $(this)).html();
+            var pool_link = $("td:nth-child(5)", $(this)).html();
 
             /* Make pool name editable */
             var input = $(']] printPoolNameField('pool_id') print[[');
@@ -1025,34 +1002,20 @@ print [[
             $("input", input).first().val(value);
             pool_name.html(input);
 
-            /* Make children safe and per-member pool quotas editable */
-            children_safe.html(makeChildrenSafeInput(children_safe.html() === "true"));
-            enforce_quotas_per_pool_member.html(makeEnforceQuotasPerPoolMemberInput(enforce_quotas_per_pool_member.html() === "true"));
-
             if (pool_id == ]]  print(host_pools_utils.DEFAULT_POOL_ID) print[[) {
               $("input", input).first().attr("disabled", "disabled");
             } else {
-              datatableAddLinkButtonCallback.bind(this)(6, pool_link, "View");
+              datatableAddLinkButtonCallback.bind(this)(4, pool_link, "View");
               value = value.replace("'", "\\'");
-              datatableAddDeleteButtonCallback.bind(this)(6, "delete_pool_id ='" + pool_id + "'; $('#delete_pool_dialog_pool').html('" + value + "'); $('#delete_pool_dialog').modal('show');", "]] print(i18n('delete')) print[[");
+              datatableAddDeleteButtonCallback.bind(this)(4, "delete_pool_id ='" + pool_id + "'; $('#delete_pool_dialog_pool').html('" + value + "'); $('#delete_pool_dialog').modal('show');", "]] print(i18n('delete')) print[[");
 
               if (pool_undeletable)
-                $("td:nth-child(6) a", $(this)).last().attr("disabled", "disabled");
+                $("td:nth-child(4) a", $(this)).last().attr("disabled", "disabled");
             }
 
             pools_ctr++;
          });
 
-         /* pick the first unused pool ID */
-         $("#table-create td:nth-child(1)").each(function() {
-            var this_pool_id = parseInt($(this).html());
-            if(nextPoolId == this_pool_id)
-               nextPoolId += 1;
-         });
-
-         if (numPools === 0)
-          numPools = pools_ctr;
-
          aysResetForm('#table-create-form');
         }
 
@@ -1074,12 +1037,7 @@ print [[
       $("input[name^='pool_']", form).each(function() {
         var pool_id = $(this).attr("name").split("pool_")[1];
 
-        var children_safe = $("input[name='children_safe']", $(this).closest("tr")).is(':checked');
-	var enforce_quotas_per_pool_member = $("input[name='enforce_quotas_per_pool_member']", $(this).closest("tr")).is(':checked');
-
         settings[pool_id] = $(this).val();
-        settings["_csafe_" + pool_id] = children_safe;
-        settings["_qts_per_member_" + pool_id] = enforce_quotas_per_pool_member;
       });
 
       // reset ays so that we can submit a custom form
