@@ -1,5 +1,5 @@
 --
--- (C) 2013-17 - ntop.org
+-- (C) 2013-18 - ntop.org
 --
 
 dirs = ntop.getDirs()
@@ -7,10 +7,12 @@ package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
 
 require "lua_utils"
 
+local page_utils = require("page_utils")
+
 sendHTTPContentTypeHeader('text/html')
 
+page_utils.print_header(i18n("geo_map.geo_map"))
 
-ntop.dumpFile(dirs.installdir .. "/httpdocs/inc/header.inc")
 active_page = "hosts"
 dofile(dirs.installdir .. "/scripts/lua/inc/menu.lua")
 
@@ -42,7 +44,7 @@ print[[
       <div id="map-canvas"></div>
 ]]
 
-ntop.dumpFile(dirs.installdir .. "/httpdocs/inc/geolocation_disclaimer.inc")
+dofile(dirs.installdir .. "/scripts/lua/show_geolocation_note.lua")
 
 print [[
 </div>
