@@ -1,17 +1,10 @@
+require("lua_utils")
 local host_pools_utils = require 'host_pools_utils'
 require("prefs_utils")
 
-local messages = {ntopng="Add Web User", captive_portal="Add Captive Portal User"}
+local messages = {ntopng=ternary(ntop.isnEdge(), i18n("nedge.add_system_user"), i18n("login.add_web_user"))}
 
 local add_user_msg = messages["ntopng"]
-local captive_portal_user = false
-if is_captive_portal_active then
-   if _GET["captive_portal_users"] ~= nil then
-      add_user_msg = messages["captive_portal"]
-      captive_portal_user = true
-   end
-end
-
 
 print [[
 <div id="add_user_dialog" class="modal fade" tabindex="-1" role="dialog" aria-labelledby="add_user_dialog_label" aria-hidden="true">
@@ -34,14 +27,16 @@ print [[
 
 </script>
 
- <form data-toggle="validator" id="form_add_user" class="form-inline" method="post" action="add_user.lua" >
+ <form data-toggle="validator" id="form_add_user" class="form-inline" method="post" action="add_user.lua" accept-charset="UTF-8">
 			   ]]
+
 print('<input id="csrf" name="csrf" type="hidden" value="'..ntop.getRandomCSRFValue()..'" />\n')
+
 print [[
 
 <div class="row">
     <div class="form-group col-md-6 has-feedback">
-      <label class="form-label">Username</label>
+      <label class="form-label">]] print(i18n("login.username")) print[[</label>
       <div class="input-group">
         <span class="input-group-addon"><i class="fa fa-user-circle-o" aria-hidden="true"></i></span>
         <input id="username_input" type="text" name="username" value="" class="form-control" pattern="^[\w]{1,}$" required>
@@ -49,7 +44,7 @@ print [[
     </div>
 
     <div class="form-group col-md-6 has-feedback">
-      <label class="form-label">Full Name</label>
+      <label class="form-label">]] print(i18n("users.full_name")) print[[</label>
       <div class="input-group">
         <span class="input-group-addon"><i class="fa fa-user" aria-hidden="true"></i></span>
         <input id="full_name_input" type="text" name="full_name" value="" class="form-control">
@@ -61,14 +56,14 @@ print [[
 
 <div class="row">
     <div class="form-group col-md-6 has-feedback">
-      <label class="form-label">Password</label>
+      <label class="form-label">]] print(i18n("login.password")) print[[</label>
       <div class="input-group"><span class="input-group-addon"><i class="fa fa-lock"></i></span>
         <input id="password_input" type="password" name="password" value="" class="form-control"  pattern="]] print(getPasswordInputPattern()) print[[" required>
       </div>
   </div>
 
     <div class="form-group col-md-6 has-feedback">
-      <label class="form-label">Confirm Password</label>
+      <label class="form-label">]] print(i18n("login.confirm_password")) print[[</label>
       <div class="input-group"><span class="input-group-addon"><i class="fa fa-lock"></i></span>
         <input id="confirm_password_input" type="password" name="confirm_password" value="" class="form-control" pattern="]] print(getPasswordInputPattern()) print[[" required>
       </div>
@@ -76,31 +71,26 @@ print [[
 </div>
 
 <br>
-
-]]
-
-if captive_portal_user == false then
-   print[[
 <div class="row">
     <div class="form-group col-md-6 has-feedback">
-      <label class="form-label">User Role</label>
+      <label class="form-label">]] print(i18n("manage_users.user_role")) print[[</label>
       <div class="input-group" style="width:100%;">
         <select id="host_role_select" name="user_role" class="form-control" style="width:100%;">
-          <option value="unprivileged">Non Privileged User</option>
-          <option value="administrator">Administrator</option>
+          <option value="unprivileged">]] print(i18n("manage_users.non_privileged_user")) print[[</option>
+          <option value="administrator">]] print(i18n("manage_users.administrator")) print[[</option>
         </select>
       </div>
   </div>
 
     <div class="form-group col-md-6 has-feedback">
-      <label class="form-label">Allowed Interface</label>
+      <label class="form-label">]] print(i18n("manage_users.allowed_interface")) print[[</label>
       <div class="input-group" style="width:100%;">
         <select name="allowed_interface" id="allowed_interface" class="form-control">
-          <option value="">Any Interface</option>
+          <option value="">]] print(i18n("manage_users.any_interface")) print[[</option>
 ]]
 
    for _, interface_name in pairsByValues(interface.getIfNames(), asc) do
-      print('<option value="'..getInterfaceId(interface_name)..'"> '..interface_name..'</option>')
+      print('<option value="'..getInterfaceId(interface_name)..'"> '..getHumanReadableInterfaceName(interface_name)..'</option>')
    end
    print[[
         </select>
@@ -112,108 +102,48 @@ if captive_portal_user == false then
 
 <div class="row">
     <div class="form-group col-md-12 has-feedback">
-      <label class="form-label">Allowed Networks</label>
+      <label class="form-label">]] print(i18n("manage_users.allowed_networks")) print[[</label>
       <div class="input-group"><span class="input-group-addon"><span class="glyphicon glyphicon-tasks"></span></span>
         <input id="allowed_networks_input" type="text" name="allowed_networks" value="" class="form-control">
       </div>
-      <small>Comma separated list of networks this user can view. Example: 192.168.1.0/24,172.16.0.0/16</small>
+      <small>]] print(i18n("manage_users.allowed_networks_descr")) print[[: 192.168.1.0/24,172.16.0.0/16</small>
     </div>
-</div>]]
-
-else -- a captive portal user is being added
-   print[[
-
-<div class="row">
-    <div class="form-group col-md-6 has-feedback">
-      <label class="form-label">Host Pool</label>
-      <div class="input-group" style="width:100%;">
-        <select name="host_pool_id" id="host_pool_id" class="form-control">
-
+</div>
+<br>
 ]]
 
-   local pools = host_pools_utils.getPoolsList(getInterfaceId(ifname))
-   local no_pools = true
+if not ntop.isnEdge() then
+  print[[
+<div class="row">
+    <div class="form-group col-md-6 has-feedback">
+      <label class="form-label">]] print(i18n("language")) print[[</label>
+      <div class="input-group">
+        <span class="input-group-addon"><i class="fa fa-language" aria-hidden="true"></i></span>
+        <select name="user_language" id="user_language" class="form-control">]]
 
-   for _, pool in ipairs(pools) do
-      if pool.id ~= host_pools_utils.DEFAULT_POOL_ID then
-        print('<option value="'.. pool.id ..'"> '.. pool.name ..'</option>')
-        no_pools = false
-      end
-   end
+  for _, lang in pairs(locales_utils.getAvailableLocales()) do
+     print('<option value="'..lang["code"]..'">'..i18n("locales." .. lang["code"])..'</option>')
+  end
 
-   print[[
+  print[[
         </select>
       </div>
-      <input id="host_role" name="user_role" type="hidden" value="captive_portal" />
-      <input id="allowed_networks" name="allowed_networks" type="hidden" value="0.0.0.0/0,::/0" />
-      <input id="allowed_interface" name="allowed_interface" type="hidden" value="]] print(tostring(getInterfaceId(ifname))) print[[" />
     </div>
 
     <div class="form-group col-md-6 has-feedback">
-      <label class="form-label">Authentication Lifetime</label>
+      <label class="form-label"></label>
       <div class="input-group">
-        <label class="radio-inline"><input type="radio" id="add_lifetime_unlimited" name="lifetime_unlimited" checked>Unlimited</label>
-        <label class="radio-inline"><input type="radio" id="add_lifetime_limited" name="lifetime_limited">Expires after</label>
       </div>
-      <!-- optionally allow to specify a certain number of days
-      <input id="add_lifetime_days" name="lifetime_days" type="number" min="1" max="100" value="" class="form-control pull-right text-right" style="display: inline; width: 8em; padding-right: 1em;" disabled required>
-      -->
     </div>
 </div>
-
-<div class="row">
-    <div class="form-group col-md-6 has-feedback">
-    </div>
-
-    <div class="col-md-6 has-feedback text-center">
-
-      <table class="form-group" id="add_lifetime_selection_table">
-        <tr>
-
-          <td style="vertical-align:top;">
+<br>
 ]]
-   --   require("prefs_utils")
-   local res = prefsResolutionButtons("hd", 3600)
-   print[[
-          </td>
-          <td style="padding-left: 2em;">
-        <input class="form-control text-right" style="display:inline; width:5em; padding-right:1em;" name="lifetime_secs" id="add_lifetime_secs" type="number" data-min="3600" value="]] print(tostring(res)) print[[">
-          </td>
-        </tr>
-      </table>
-    </div>
-</div>
-
-<div class="row">
-  <div class='col-md-6'>
-    <small>The host pool that will be associated to the user upon successful authentication.</small>
-  </div>
-  <div class='col-md-6'>
-    <small>The authentication can be perpetual or can expire after the specified time.</small>
-  </div>
-</div>
-
-]]
-
-if no_pools then
-  print[[
-    <script>
-      $(function() {
-        add_user_alert.error("No Host Pools defined. Please create one <a href=']] print(ntop.getHttpPrefix()) print[[/lua/if_stats.lua?page=pools#create'>here</a>.", true);
-        $("#add_user_dialog").find("input,select,button[type='submit']").attr("disabled", "disabled");
-      });
-    </script>
-  ]]
-end
-
 end
 
 print[[
-<br>
-
 <div class="row">
     <div class="form-group col-md-12 has-feedback">
-      <button type="submit" id="add_user_submit" class="btn btn-primary btn-block">Add New User</button>
+      <button type="submit" id="add_user_submit" class="btn btn-primary btn-block">]] print(i18n("manage_users.add_new_user")) print[[</button>
     </div>
 </div>
 
@@ -226,13 +156,13 @@ print[[
   $("#add_lifetime_unlimited").click(function(){
     $("#add_lifetime_selection_table label").attr("disabled", "disabled");
     $("#add_lifetime_selection_table input").attr("disabled", "disabled");
-    $("#add_lifetime_limited").removeAttr("checked");
+    $("#add_lifetime_limited").removeAttr("checked").prop("checked", false);
   });
 
   $("#add_lifetime_limited").click(function() {
     $("#add_lifetime_selection_table label").removeAttr("disabled");
     $("#add_lifetime_selection_table input").removeAttr("disabled");
-    $("#add_lifetime_unlimited").removeAttr("checked");
+    $("#add_lifetime_unlimited").removeAttr("checked").prop("checked", false);
   });
 
   var frmadduser = $('#form_add_user');
@@ -278,14 +208,9 @@ print[[
       return(false);
     }
 
-    // escape characters to send out valid latin-1 encoded characters
-    $('#password_input').val(escape($('#password_input').val()))
-    $('#confirm_password_input').val(escape($('#confirm_password_input').val()))
-]]
-
-if captive_portal_user == false then
-   -- network validation only for captive portal users
-   print[[
+    // Don't do any escape, form contain Unicode UTF-8 encoded chars
+    // ('#password_input').val(escape($('#password_input').val()))
+    // $('#confirm_password_input').val(escape($('#confirm_password_input').val()))
     if($("#allowed_networks_input").val().length == 0) {
       add_user_alert.error("Network list not specified");
       return(false);
@@ -298,27 +223,15 @@ if captive_portal_user == false then
         }
       }
     }]]
-end
+
 
 local location_href = ntop.getHttpPrefix().."/lua/admin/users.lua"
-if captive_portal_user then
-   location_href = location_href.."?captive_portal_users=1"
-end
 
 print[[
     $.getJSON(']]  print(ntop.getHttpPrefix())  print[[/lua/admin/validate_new_user.lua?username='+$("#username_input").val()+"&allowed_networks="+$("#allowed_networks_input").val(), function(data){
       if (!data.valid) {
         add_user_alert.error(data.msg);
       } else {
-]]
-
-if captive_portal_user == true then
-  print[[
-        /* Converts expire resolution into appropriate value */
-        resol_selector_finalize(frmadduser);]]
-end
-
-print[[
         $.ajax({
           type: frmadduser.attr('method'),
           url: frmadduser.attr('action'),
