@@ -1,5 +1,5 @@
 --
--- (C) 2013-17 - ntop.org
+-- (C) 2013-18 - ntop.org
 --
 
 dirs = ntop.getDirs()
@@ -7,9 +7,11 @@ package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
 
 require "lua_utils"
 
+local page_utils = require("page_utils")
+
 sendHTTPContentTypeHeader('text/html')
 
-ntop.dumpFile(dirs.installdir .. "/httpdocs/inc/header.inc")
+page_utils.print_header(i18n("operating_systems"))
 
 active_page = "hosts"
 dofile(dirs.installdir .. "/scripts/lua/inc/menu.lua")
@@ -64,8 +66,69 @@ print [[
 				 },
 			  ]]
 
+print [[
+			     {
+			     title: "]] print(i18n("hosts_stats.hosts")) print[[",
+				 field: "column_hosts",
+				 sortable: true,
+                             css: {
+			        textAlign: 'center'
+			     }
 
-ntop.dumpFile(dirs.installdir .. "/httpdocs/inc/os_stats_top.inc")
+				 },
+			     {
+			     title: "]] print(i18n("show_alerts.alerts")) print[[",
+				 field: "column_alerts",
+				 sortable: true,
+                             css: {
+			        textAlign: 'center'
+			     }
+
+				 },
+		
+			     {
+			     title: "]] print(i18n("seen_since")) print[[",
+				 field: "column_since",
+				 sortable: true,
+                             css: {
+			        textAlign: 'center'
+			     }
+
+				 },
+
+]]
+
+print [[
+			     {
+			     title: "]] print(i18n("breakdown")) print[[",
+				 field: "column_breakdown",
+				 sortable: false,
+	 	             css: {
+			        textAlign: 'center'
+			     }
+				 },
+			     {
+			     title: "]] print(i18n("throughput")) print[[",
+				 field: "column_thpt",
+				 sortable: true,
+	 	             css: {
+			        textAlign: 'right'
+			     }
+				 },
+			     {
+			     title: "]] print(i18n("traffic")) print[[",
+				 field: "column_traffic",
+				 sortable: true,
+	 	             css: {
+			        textAlign: 'right'
+			     }
+				 }
+			     ]
+	       });
+
+
+       </script>
+
+]]
 
-ntop.dumpFile(dirs.installdir .. "/httpdocs/inc/hosts_stats_bottom.inc")
 dofile(dirs.installdir .. "/scripts/lua/inc/footer.lua")
